from setuptools import setup, Extension

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
  name = 'letesend',         # How you named your package folder (MyLib)
  packages = ['letesend'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Letesend sdk for sending and monitoring SMS',   # Give a short description about your library
  long_description=long_description,
   long_description_content_type="text/markdown",
  author = 'Letesend',                   # Type in your name
  author_email = 'support@letesend.com',      # Type in your E-Mail
  url = 'https://github.com/letesend/python',   # Provide either the link to your github or to your website
#  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['letesend', 'letesend python', 'letesend-python', 'python letesend', 'python-letesend'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
        'requests',
    ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3', 
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)


import requests

class SMS:
    """
    Letesend sdk for sending and monitoring SMS
    """

    url = "https://apis.letesend.com/sms/"


    def __init__(self, auth_token, debug=False):
        self.id          = ''
        self.to          = ''
        self.name        = ''
        self.body        = ''
        self.status      = ''
        self.date        = ''
        self.time        = ''
        self.status_code = ''
        self.status_text = ''
        self.ok          = False
        self.auth_token  = auth_token
        self.debug       = debug


    def headers(self):
        """
        Http Request Headers
        """
        return {
            'Authorization': 'Token {}'.format(self.auth_token)
        }


    def __setResponse(self, response):
        """
        Set server response to object attributes
        """
        self.status_code = response.status_code
        self.status_text = response.json()
        self.ok = response.ok
        if self.ok:
            try:
                self.id = response.json()['id']
                self.to = response.json()['to']
                self.name = response.json()['name']
                self.body = response.json()['body']
                self.status = response.json()['status']
                self.date = response.json()['date']
                self.time = response.json()['time']
            except:
                pass


    def is_debug(self, *args):
        """
        Logging if debug mode is True.
        e.g. in development
        """
        if self.debug:
            #Logging
            pass


    def send(self, to=None, name='LeteSend', body='Hello World !'):
        """
        Send SMS
        --------
        @to: Phone Number E.164 format
        @name: Company name, will be display on SMS Header
        @body: The Message body, 160 caracteres per SMS
        """

        payload = {
            "to"  : to,
            "name": name,    
            "body": body
        }

        #self.is_debug("\nSending SMS ...")

        response = requests.request(
            method  = "POST", 
            url     = self.url, 
            headers = self.headers(), 
            data    = payload)

        #self.is_debug(response.status_code, response.text)
        self.__setResponse(response)

        return response
